@@ -33,7 +33,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-profile_file="/var/cache/univention-system-setup/profile"
+USS_PROFILE='/var/cache/univention-system-setup/profile'
 check_ldap_access=0
 
 export TEXTDOMAIN="univention-system-setup-scripts"
@@ -61,6 +61,7 @@ done
 # @param  script path
 # @param  description (optional)
 info_header () {
+	local _path script name
 	_path="$1"
 	script="${_path##*scripts/}"
 	echo "=== $script ($(date +'%Y-%m-%d %H:%M:%S')) ==="
@@ -109,33 +110,25 @@ progress_next_step () {
 	fi
 }
 
-is_variable_set () {
-	[ -e "$profile_file" ] ||
+is_variable_set () {  # DEPRECATED: has inverted logic
+	[ -e "$USS_PROFILE" ] ||
 		return 0
 	[ -n "$1" ] ||
 		return 0
-	value="$(grep -E "^$1=" "$profile_file")"
+	value="$(grep -E "^$1=" "$USS_PROFILE")"
 	[ -z "$value" ]
 }
 get_profile_var () {
-	[ -e "$profile_file" ] ||
-		return
-	[ -n "$1" ] ||
-		return
-	sed -rne "/^ *#/d;s|^$1=||;T;s|([\"'])(.*)\1 *\$|\2|;p;q" "$profile_file"
+	[ -e "$USS_PROFILE" ] &&
+	[ -n "$1" ] &&
+	! sed -rne "/^ *#/d;s|^$1=||;T;s|([\"'])(.*)\1 *\$|\2|;p;q 1" "$USS_PROFILE"
 }
-
 is_profile_var_true () {
-	local value
-	value="$(get_profile_var "$1")"
-	[ -n "$value" ] ||
-		return 2
-	value="$(echo "$value" | tr '[:upper:]' '[:lower:]')"
-	for falsevalue in no false 0 disable disabled off; do
-		[ "$value" = "$falsevalue" ] &&
-			return 1
-	done
-	return 0
+	case "$(get_profile_var "$1" | tr '[:upper:]' '[:lower:]')" in
+	'') return 2 ;;
+	false|0|disable|disabled|off) return 1 ;;
+	*) return 0 ;;
+	esac
 }
 
 service () {
@@ -161,6 +154,7 @@ service_start () { service start "$@"; }
 service_stop () { service stop "$@"; }
 
 ldap_binddn () {
+	local server_role ldap_base ldap_master ldap_hostdn ldap_username
 	eval "$(univention-config-registry shell server/role ldap/base ldap/master ldap/hostdn)"
 	case "${server_role:?}" in
 	domaincontroller_master|domaincontroller_backup)
@@ -176,8 +170,7 @@ ldap_binddn () {
 }
 
 ldap_bindpwd () {
-	eval "$(univention-config-registry shell server/role ldap/base ldap/master)"
-	case "${server_role:?}" in
+	case "$(ucr get server/role)" in
 	domaincontroller_master|domaincontroller_backup)
 		cat /etc/ldap.secret
 		;;
